pub struct Analysis {
pub id: AnalysisId,
pub features: [f64; 20],
}Expand description
Fields
id: AnalysisIdthe unique identifier for this Analysis.
features: [f64; 20]The [Song]’s audio features.
Implementations
Sourceimpl Analysis
impl Analysis
Sourcepub async fn create<C: Connection>(
db: &Surreal<C>,
song_id: SongId,
analysis: Self,
) -> StorageResult<Option<Self>>
pub async fn create<C: Connection>( db: &Surreal<C>, song_id: SongId, analysis: Self, ) -> StorageResult<Option<Self>>
create a new analysis for the given song
If an analysis already exists for the song, this will return None.
pub async fn read<C: Connection>( db: &Surreal<C>, id: AnalysisId, ) -> StorageResult<Option<Self>>
pub async fn read_all<C: Connection>( db: &Surreal<C>, ) -> StorageResult<Vec<Self>>
Sourcepub async fn read_for_song<C: Connection>(
db: &Surreal<C>,
song_id: SongId,
) -> StorageResult<Option<Self>>
pub async fn read_for_song<C: Connection>( db: &Surreal<C>, song_id: SongId, ) -> StorageResult<Option<Self>>
Read the analysis for a song
If the song does not have an analysis, this will return None.
Sourcepub async fn read_for_songs<C: Connection>(
db: &Surreal<C>,
song_ids: Vec<SongId>,
) -> StorageResult<Vec<Option<Self>>>
pub async fn read_for_songs<C: Connection>( db: &Surreal<C>, song_ids: Vec<SongId>, ) -> StorageResult<Vec<Option<Self>>>
Read the analysis for OneOrMany song(s)
Needed for clustering(?)
We return a Vec<Option
Sourcepub async fn read_song<C: Connection>(
db: &Surreal<C>,
id: AnalysisId,
) -> StorageResult<Song>
pub async fn read_song<C: Connection>( db: &Surreal<C>, id: AnalysisId, ) -> StorageResult<Song>
Read the song for an analysis
Sourcepub async fn read_songs<C: Connection>(
db: &Surreal<C>,
ids: OneOrMany<AnalysisId>,
) -> StorageResult<OneOrMany<Song>>
pub async fn read_songs<C: Connection>( db: &Surreal<C>, ids: OneOrMany<AnalysisId>, ) -> StorageResult<OneOrMany<Song>>
Read the song for OneOrMany analyses
needed to convert a list of analyses (such as what we get from nearest_neighbors) into a list of songs
Sourcepub async fn read_songs_without_analysis<C: Connection>(
db: &Surreal<C>,
) -> StorageResult<Vec<Song>>
pub async fn read_songs_without_analysis<C: Connection>( db: &Surreal<C>, ) -> StorageResult<Vec<Song>>
Get all the songs that don’t have an analysis
Sourcepub async fn delete<C: Connection>(
db: &Surreal<C>,
id: AnalysisId,
) -> StorageResult<Option<Self>>
pub async fn delete<C: Connection>( db: &Surreal<C>, id: AnalysisId, ) -> StorageResult<Option<Self>>
Delete an analysis
Sourcepub async fn nearest_neighbors<C: Connection>(
db: &Surreal<C>,
id: AnalysisId,
n: u32,
) -> StorageResult<Vec<Self>>
pub async fn nearest_neighbors<C: Connection>( db: &Surreal<C>, id: AnalysisId, n: u32, ) -> StorageResult<Vec<Self>>
Find the n nearest neighbors to an analysis
Sourcepub async fn nearest_neighbors_to_many<C: Connection>(
db: &Surreal<C>,
ids: Vec<AnalysisId>,
n: u32,
) -> StorageResult<Vec<Self>>
pub async fn nearest_neighbors_to_many<C: Connection>( db: &Surreal<C>, ids: Vec<AnalysisId>, n: u32, ) -> StorageResult<Vec<Self>>
Find the n nearest neighbors to a list of analyses
The provided analyses should not be included in the results
Sourceimpl Analysis
impl Analysis
pub fn generate_id() -> AnalysisId