pub struct Collection {
pub id: CollectionId,
pub name: String,
pub runtime: Duration,
pub song_count: usize,
}Fields
id: CollectionIdthe unique identifier for this Collection.
name: StringThe name of the collection.
runtime: DurationTotal runtime.
song_count: usizethe number of songs this collection has.
Implementations
Sourceimpl Collection
impl Collection
pub async fn create<C: Connection>( db: &Surreal<C>, collection: Self, ) -> StorageResult<Option<Self>>
pub async fn read_all<C: Connection>( db: &Surreal<C>, ) -> StorageResult<Vec<Self>>
pub async fn read<C: Connection>( db: &Surreal<C>, id: CollectionId, ) -> StorageResult<Option<Self>>
pub async fn update<C: Connection>( db: &Surreal<C>, id: CollectionId, changes: CollectionChangeSet, ) -> StorageResult<Option<Self>>
pub async fn delete<C: Connection>( db: &Surreal<C>, id: CollectionId, ) -> StorageResult<Option<Self>>
pub async fn add_songs<C: Connection>( db: &Surreal<C>, id: CollectionId, song_ids: Vec<SongId>, ) -> StorageResult<()>
pub async fn read_songs<C: Connection>( db: &Surreal<C>, id: CollectionId, ) -> StorageResult<Vec<Song>>
Sourcepub async fn remove_songs<C: Connection>(
db: &Surreal<C>,
id: CollectionId,
song_ids: Vec<SongId>,
) -> StorageResult<bool>
pub async fn remove_songs<C: Connection>( db: &Surreal<C>, id: CollectionId, song_ids: Vec<SongId>, ) -> StorageResult<bool>
Sourcepub async fn repair<C: Connection>(
db: &Surreal<C>,
id: CollectionId,
) -> StorageResult<bool>
pub async fn repair<C: Connection>( db: &Surreal<C>, id: CollectionId, ) -> StorageResult<bool>
Sourcepub async fn freeze<C: Connection>(
db: &Surreal<C>,
id: CollectionId,
name: String,
) -> StorageResult<Playlist>
pub async fn freeze<C: Connection>( db: &Surreal<C>, id: CollectionId, name: String, ) -> StorageResult<Playlist>
“Freeze” a collection, this will create a playlist with the given name that contains all the songs in the given collection
Sourceimpl Collection
impl Collection
pub fn generate_id() -> CollectionId