Module test_utils

Structs

SongCase

Enums

IndexMode
RangeEndMode
RangeIndexMode
RangeStartMode

Constants

ARTIST_NAME_SEPARATOR

Functions

arb_analysis_features
arb_song_case
arb_vec
arb_vec_and_index
arb_vec_and_range_and_index
create_song_metadata
Creates a song file with the given case and overrides. The song file is created in a temporary directory. The song metadata is created from the song file. The song is not added to the database.
create_song_with_overrides
Create a song with the given case, and optionally apply the given overrides.
init_test_database
Initialize a test database with the same tables as the main database. This is useful for testing queries and mutations.
init_test_database_with_state
Initialize a test database with some basic state